// Saturn Fenrir ODE (Optical Drive Emulator) Micro SD Extender Cover

// Original cover hollow was the wrong size for many commonly available extenders.

// This remake cover is designed to work with the ODE base from https://www.thingiverse.com/thing:3927079 by Zitruskeks

// Logo exported from Inkscape to .dxf file using https://github.com/brad/Inkscape-OpenSCAD-DXF-Export

/////////////////////////////
// Define variables
/////////////////////////////
CoverX = 38.4; // Overall width of the case

CoverY = 40.7; // Overall depth of the case

CoverZ = 9; // Overall height of the case

ScrewHoleOffset = 21; // Distance from back of case to center of screw holes

ScrewHoleWidth = 34; // Center-to-center distance between holes

ScrewHoleDia = 2.5; // Screw hole diameter

CaseX = 25; // Overall width of the extender case

CaseY = 33; // Overall depth of the extender case

CaseZ = 7.4; // Overall Height of the extender case

CornerDia = 6; // Corner diameter on the extender case

CaseOffset = 0.1; // Distance the extender case protrudes beyond the cover

RibbonWidth = 21; // Ribbon cable width

RibbonDepth = 6; // Y-axis distance to allow ribbon cable to bend

LogoX = 32.15; //Logo X-axis size

LogoY = 21.7; //Logo Y-axis size

LogoDepth = 0.5; // Depth of the logo

CurveDia = 40; // Diameter of the front curve

CurveOffset = 32.5; // Distance past the front edge of the cover to place the front curve cylinder

// Number of fragments (polygon sides) used to render a full circle.
    $fn = 180; // Default = 180  Typical range = 6 - 360
    // 6 will render a circular hole as a hexagon, 8 will render a circular hole as an octagon.
    // Lower the number for faster rendering, raise the number for smoother rendering.

/////////////////////////////
//  Make the part
/////////////////////////////

difference(){ // Cover minus Saturn Logo, screw holes, extender case, ribbon cable space, and front curve

// Cover
    translate ([0, -CoverY/2, CoverZ/2])
    cube ([CoverX, CoverY, CoverZ], center=true);
    //

// Saturn Logo (Optional)
    // Comment out the next four lines to skip the logo.
    translate([-LogoX/2, -CoverY/2 - LogoY/2, CoverZ - LogoDepth + 0.01])
    resize(newsize=[LogoX ,LogoY ,LogoDepth])
    linear_extrude(height = LogoDepth, convexity = 10)
    import(file = "Saturn_Logo.dxf", layer="Logo"); // Saturn logo
    // The "Saturn_Logo.dxf" file needs to be in the same directory as this OpenSCAD file.
    
// Screw holes
    translate([-ScrewHoleWidth/2, -ScrewHoleOffset, CoverZ/4])
    cylinder (CoverZ/2 + 0.1, d = ScrewHoleDia, center=true); // Left screw hole

    translate([ScrewHoleWidth/2, -ScrewHoleOffset, CoverZ/4])
    cylinder (CoverZ/2 + 0.1, d = ScrewHoleDia, center=true); // Right screw hole

// Extender case
    hull() {
        translate([CaseX/2 - CornerDia/2, -CoverY + CaseY  - CornerDia/2 - CaseOffset, CaseZ/2])
        cylinder (CaseZ + 0.01, d = CornerDia, center=true); // Back right corner

        translate([CaseX/2 - CornerDia/2, -CoverY + CornerDia/2 - CaseOffset, CaseZ/2])
        cylinder (CaseZ + 0.01, d = CornerDia, center=true); // Front right corner

        translate([-CaseX/2 + CornerDia/2, -CoverY + CornerDia/2 - CaseOffset, CaseZ/2])
        cylinder (CaseZ + 0.01, d = CornerDia, center=true); // Front left corner

        translate([-CaseX/2 + CornerDia/2, -CoverY + CaseY  - CornerDia/2 - CaseOffset, CaseZ/2])
        cylinder (CaseZ + 0.01, d = CornerDia, center=true); // Back left corner

    } // End extender case

// Ribbon cable space
    translate ([0, -CoverY + CaseY + RibbonDepth/2 - CaseOffset - 0.1, CaseZ/2])
    cube ([RibbonWidth, RibbonDepth, CaseZ + 0.01], center=true);

// Front curve
        translate([0, -CoverY - CurveOffset/2, CoverZ/2])
        cylinder (CoverZ + 0.1, d = CurveDia, center=true);

} // End difference
//